# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _vocoder_swig
else:
    import _vocoder_swig

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def high_res_timer_now() -> "gr::high_res_timer_type":
    r"""high_res_timer_now() -> gr::high_res_timer_type"""
    return _vocoder_swig.high_res_timer_now()

def high_res_timer_now_perfmon() -> "gr::high_res_timer_type":
    r"""high_res_timer_now_perfmon() -> gr::high_res_timer_type"""
    return _vocoder_swig.high_res_timer_now_perfmon()

def high_res_timer_tps() -> "gr::high_res_timer_type":
    r"""high_res_timer_tps() -> gr::high_res_timer_type"""
    return _vocoder_swig.high_res_timer_tps()

def high_res_timer_epoch() -> "gr::high_res_timer_type":
    r"""high_res_timer_epoch() -> gr::high_res_timer_type"""
    return _vocoder_swig.high_res_timer_epoch()
class alaw_decode_bs(object):
    r"""Proxy of C++ gr::vocoder::alaw_decode_bs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::alaw_decode_bs::sptr":
        r"""make() -> alaw_decode_bs_sptr"""
        return _vocoder_swig.alaw_decode_bs_make()
    __swig_destroy__ = _vocoder_swig.delete_alaw_decode_bs

# Register alaw_decode_bs in _vocoder_swig:
_vocoder_swig.alaw_decode_bs_swigregister(alaw_decode_bs)

def alaw_decode_bs_make() -> "gr::vocoder::alaw_decode_bs::sptr":
    r"""alaw_decode_bs_make() -> alaw_decode_bs_sptr"""
    return _vocoder_swig.alaw_decode_bs_make()

class alaw_encode_sb(object):
    r"""Proxy of C++ gr::vocoder::alaw_encode_sb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::alaw_encode_sb::sptr":
        r"""make() -> alaw_encode_sb_sptr"""
        return _vocoder_swig.alaw_encode_sb_make()
    __swig_destroy__ = _vocoder_swig.delete_alaw_encode_sb

# Register alaw_encode_sb in _vocoder_swig:
_vocoder_swig.alaw_encode_sb_swigregister(alaw_encode_sb)

def alaw_encode_sb_make() -> "gr::vocoder::alaw_encode_sb::sptr":
    r"""alaw_encode_sb_make() -> alaw_encode_sb_sptr"""
    return _vocoder_swig.alaw_encode_sb_make()

class cvsd_decode_bs(object):
    r"""Proxy of C++ gr::vocoder::cvsd_decode_bs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(min_step: "short"=10, max_step: "short"=1280, step_decay: "double"=0.9990234375, accum_decay: "double"=0.96875, K: "int"=32, J: "int"=4, pos_accum_max: "short"=32767, neg_accum_max: "short"=-32767) -> "gr::vocoder::cvsd_decode_bs::sptr":
        r"""make(short min_step=10, short max_step=1280, double step_decay=0.9990234375, double accum_decay=0.96875, int K=32, int J=4, short pos_accum_max=32767, short neg_accum_max=-32767) -> cvsd_decode_bs_sptr"""
        return _vocoder_swig.cvsd_decode_bs_make(min_step, max_step, step_decay, accum_decay, K, J, pos_accum_max, neg_accum_max)

    def min_step(self) -> "short":
        r"""min_step(cvsd_decode_bs self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_min_step(self)

    def max_step(self) -> "short":
        r"""max_step(cvsd_decode_bs self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_max_step(self)

    def step_decay(self) -> "double":
        r"""step_decay(cvsd_decode_bs self) -> double"""
        return _vocoder_swig.cvsd_decode_bs_step_decay(self)

    def accum_decay(self) -> "double":
        r"""accum_decay(cvsd_decode_bs self) -> double"""
        return _vocoder_swig.cvsd_decode_bs_accum_decay(self)

    def K(self) -> "int":
        r"""K(cvsd_decode_bs self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_K(self)

    def J(self) -> "int":
        r"""J(cvsd_decode_bs self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_J(self)

    def pos_accum_max(self) -> "short":
        r"""pos_accum_max(cvsd_decode_bs self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_pos_accum_max(self)

    def neg_accum_max(self) -> "short":
        r"""neg_accum_max(cvsd_decode_bs self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_neg_accum_max(self)
    __swig_destroy__ = _vocoder_swig.delete_cvsd_decode_bs

# Register cvsd_decode_bs in _vocoder_swig:
_vocoder_swig.cvsd_decode_bs_swigregister(cvsd_decode_bs)

def cvsd_decode_bs_make(min_step: "short"=10, max_step: "short"=1280, step_decay: "double"=0.9990234375, accum_decay: "double"=0.96875, K: "int"=32, J: "int"=4, pos_accum_max: "short"=32767, neg_accum_max: "short"=-32767) -> "gr::vocoder::cvsd_decode_bs::sptr":
    r"""cvsd_decode_bs_make(short min_step=10, short max_step=1280, double step_decay=0.9990234375, double accum_decay=0.96875, int K=32, int J=4, short pos_accum_max=32767, short neg_accum_max=-32767) -> cvsd_decode_bs_sptr"""
    return _vocoder_swig.cvsd_decode_bs_make(min_step, max_step, step_decay, accum_decay, K, J, pos_accum_max, neg_accum_max)

class cvsd_encode_sb(object):
    r"""Proxy of C++ gr::vocoder::cvsd_encode_sb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    @staticmethod
    def make(min_step: "short"=10, max_step: "short"=1280, step_decay: "double"=0.9990234375, accum_decay: "double"=0.96875, K: "int"=32, J: "int"=4, pos_accum_max: "short"=32767, neg_accum_max: "short"=-32767) -> "gr::vocoder::cvsd_encode_sb::sptr":
        r"""make(short min_step=10, short max_step=1280, double step_decay=0.9990234375, double accum_decay=0.96875, int K=32, int J=4, short pos_accum_max=32767, short neg_accum_max=-32767) -> cvsd_encode_sb_sptr"""
        return _vocoder_swig.cvsd_encode_sb_make(min_step, max_step, step_decay, accum_decay, K, J, pos_accum_max, neg_accum_max)

    def min_step(self) -> "short":
        r"""min_step(cvsd_encode_sb self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_min_step(self)

    def max_step(self) -> "short":
        r"""max_step(cvsd_encode_sb self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_max_step(self)

    def step_decay(self) -> "double":
        r"""step_decay(cvsd_encode_sb self) -> double"""
        return _vocoder_swig.cvsd_encode_sb_step_decay(self)

    def accum_decay(self) -> "double":
        r"""accum_decay(cvsd_encode_sb self) -> double"""
        return _vocoder_swig.cvsd_encode_sb_accum_decay(self)

    def K(self) -> "int":
        r"""K(cvsd_encode_sb self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_K(self)

    def J(self) -> "int":
        r"""J(cvsd_encode_sb self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_J(self)

    def pos_accum_max(self) -> "short":
        r"""pos_accum_max(cvsd_encode_sb self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_pos_accum_max(self)

    def neg_accum_max(self) -> "short":
        r"""neg_accum_max(cvsd_encode_sb self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_neg_accum_max(self)
    __swig_destroy__ = _vocoder_swig.delete_cvsd_encode_sb

# Register cvsd_encode_sb in _vocoder_swig:
_vocoder_swig.cvsd_encode_sb_swigregister(cvsd_encode_sb)

def cvsd_encode_sb_make(min_step: "short"=10, max_step: "short"=1280, step_decay: "double"=0.9990234375, accum_decay: "double"=0.96875, K: "int"=32, J: "int"=4, pos_accum_max: "short"=32767, neg_accum_max: "short"=-32767) -> "gr::vocoder::cvsd_encode_sb::sptr":
    r"""cvsd_encode_sb_make(short min_step=10, short max_step=1280, double step_decay=0.9990234375, double accum_decay=0.96875, int K=32, int J=4, short pos_accum_max=32767, short neg_accum_max=-32767) -> cvsd_encode_sb_sptr"""
    return _vocoder_swig.cvsd_encode_sb_make(min_step, max_step, step_decay, accum_decay, K, J, pos_accum_max, neg_accum_max)

class g721_decode_bs(object):
    r"""Proxy of C++ gr::vocoder::g721_decode_bs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::g721_decode_bs::sptr":
        r"""make() -> g721_decode_bs_sptr"""
        return _vocoder_swig.g721_decode_bs_make()
    __swig_destroy__ = _vocoder_swig.delete_g721_decode_bs

# Register g721_decode_bs in _vocoder_swig:
_vocoder_swig.g721_decode_bs_swigregister(g721_decode_bs)

def g721_decode_bs_make() -> "gr::vocoder::g721_decode_bs::sptr":
    r"""g721_decode_bs_make() -> g721_decode_bs_sptr"""
    return _vocoder_swig.g721_decode_bs_make()

class g721_encode_sb(object):
    r"""Proxy of C++ gr::vocoder::g721_encode_sb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::g721_encode_sb::sptr":
        r"""make() -> g721_encode_sb_sptr"""
        return _vocoder_swig.g721_encode_sb_make()
    __swig_destroy__ = _vocoder_swig.delete_g721_encode_sb

# Register g721_encode_sb in _vocoder_swig:
_vocoder_swig.g721_encode_sb_swigregister(g721_encode_sb)

def g721_encode_sb_make() -> "gr::vocoder::g721_encode_sb::sptr":
    r"""g721_encode_sb_make() -> g721_encode_sb_sptr"""
    return _vocoder_swig.g721_encode_sb_make()

class g723_24_decode_bs(object):
    r"""Proxy of C++ gr::vocoder::g723_24_decode_bs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::g723_24_decode_bs::sptr":
        r"""make() -> g723_24_decode_bs_sptr"""
        return _vocoder_swig.g723_24_decode_bs_make()
    __swig_destroy__ = _vocoder_swig.delete_g723_24_decode_bs

# Register g723_24_decode_bs in _vocoder_swig:
_vocoder_swig.g723_24_decode_bs_swigregister(g723_24_decode_bs)

def g723_24_decode_bs_make() -> "gr::vocoder::g723_24_decode_bs::sptr":
    r"""g723_24_decode_bs_make() -> g723_24_decode_bs_sptr"""
    return _vocoder_swig.g723_24_decode_bs_make()

class g723_24_encode_sb(object):
    r"""Proxy of C++ gr::vocoder::g723_24_encode_sb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::g723_24_encode_sb::sptr":
        r"""make() -> g723_24_encode_sb_sptr"""
        return _vocoder_swig.g723_24_encode_sb_make()
    __swig_destroy__ = _vocoder_swig.delete_g723_24_encode_sb

# Register g723_24_encode_sb in _vocoder_swig:
_vocoder_swig.g723_24_encode_sb_swigregister(g723_24_encode_sb)

def g723_24_encode_sb_make() -> "gr::vocoder::g723_24_encode_sb::sptr":
    r"""g723_24_encode_sb_make() -> g723_24_encode_sb_sptr"""
    return _vocoder_swig.g723_24_encode_sb_make()

class g723_40_decode_bs(object):
    r"""Proxy of C++ gr::vocoder::g723_40_decode_bs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::g723_40_decode_bs::sptr":
        r"""make() -> g723_40_decode_bs_sptr"""
        return _vocoder_swig.g723_40_decode_bs_make()
    __swig_destroy__ = _vocoder_swig.delete_g723_40_decode_bs

# Register g723_40_decode_bs in _vocoder_swig:
_vocoder_swig.g723_40_decode_bs_swigregister(g723_40_decode_bs)

def g723_40_decode_bs_make() -> "gr::vocoder::g723_40_decode_bs::sptr":
    r"""g723_40_decode_bs_make() -> g723_40_decode_bs_sptr"""
    return _vocoder_swig.g723_40_decode_bs_make()

class g723_40_encode_sb(object):
    r"""Proxy of C++ gr::vocoder::g723_40_encode_sb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::g723_40_encode_sb::sptr":
        r"""make() -> g723_40_encode_sb_sptr"""
        return _vocoder_swig.g723_40_encode_sb_make()
    __swig_destroy__ = _vocoder_swig.delete_g723_40_encode_sb

# Register g723_40_encode_sb in _vocoder_swig:
_vocoder_swig.g723_40_encode_sb_swigregister(g723_40_encode_sb)

def g723_40_encode_sb_make() -> "gr::vocoder::g723_40_encode_sb::sptr":
    r"""g723_40_encode_sb_make() -> g723_40_encode_sb_sptr"""
    return _vocoder_swig.g723_40_encode_sb_make()

class ulaw_decode_bs(object):
    r"""Proxy of C++ gr::vocoder::ulaw_decode_bs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::ulaw_decode_bs::sptr":
        r"""make() -> ulaw_decode_bs_sptr"""
        return _vocoder_swig.ulaw_decode_bs_make()
    __swig_destroy__ = _vocoder_swig.delete_ulaw_decode_bs

# Register ulaw_decode_bs in _vocoder_swig:
_vocoder_swig.ulaw_decode_bs_swigregister(ulaw_decode_bs)

def ulaw_decode_bs_make() -> "gr::vocoder::ulaw_decode_bs::sptr":
    r"""ulaw_decode_bs_make() -> ulaw_decode_bs_sptr"""
    return _vocoder_swig.ulaw_decode_bs_make()

class ulaw_encode_sb(object):
    r"""Proxy of C++ gr::vocoder::ulaw_encode_sb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make() -> "gr::vocoder::ulaw_encode_sb::sptr":
        r"""make() -> ulaw_encode_sb_sptr"""
        return _vocoder_swig.ulaw_encode_sb_make()
    __swig_destroy__ = _vocoder_swig.delete_ulaw_encode_sb

# Register ulaw_encode_sb in _vocoder_swig:
_vocoder_swig.ulaw_encode_sb_swigregister(ulaw_encode_sb)

def ulaw_encode_sb_make() -> "gr::vocoder::ulaw_encode_sb::sptr":
    r"""ulaw_encode_sb_make() -> ulaw_encode_sb_sptr"""
    return _vocoder_swig.ulaw_encode_sb_make()

class alaw_decode_bs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::alaw_decode_bs > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(alaw_decode_bs_sptr self) -> alaw_decode_bs_sptr
        __init__(alaw_decode_bs_sptr self, alaw_decode_bs p) -> alaw_decode_bs_sptr
        """
        _vocoder_swig.alaw_decode_bs_sptr_swiginit(self, _vocoder_swig.new_alaw_decode_bs_sptr(*args))

    def __deref__(self) -> "gr::vocoder::alaw_decode_bs *":
        r"""__deref__(alaw_decode_bs_sptr self) -> alaw_decode_bs"""
        return _vocoder_swig.alaw_decode_bs_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_alaw_decode_bs_sptr

    def make(self) -> "gr::vocoder::alaw_decode_bs::sptr":
        r"""make(alaw_decode_bs_sptr self) -> alaw_decode_bs_sptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(alaw_decode_bs_sptr self) -> unsigned int"""
        return _vocoder_swig.alaw_decode_bs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(alaw_decode_bs_sptr self, int which, int delay)
        declare_sample_delay(alaw_decode_bs_sptr self, unsigned int delay)
        """
        return _vocoder_swig.alaw_decode_bs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(alaw_decode_bs_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.alaw_decode_bs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(alaw_decode_bs_sptr self, int multiple)"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(alaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.alaw_decode_bs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(alaw_decode_bs_sptr self) -> double"""
        return _vocoder_swig.alaw_decode_bs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(alaw_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.alaw_decode_bs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(alaw_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.alaw_decode_bs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(alaw_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.alaw_decode_bs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(alaw_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.alaw_decode_bs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(alaw_decode_bs_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.alaw_decode_bs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(alaw_decode_bs_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.alaw_decode_bs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(alaw_decode_bs_sptr self, std::string level)"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(alaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.alaw_decode_bs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(alaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.alaw_decode_bs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(alaw_decode_bs_sptr self, int m)"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(alaw_decode_bs_sptr self)"""
        return _vocoder_swig.alaw_decode_bs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(alaw_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.alaw_decode_bs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(alaw_decode_bs_sptr self, int m)"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(alaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.alaw_decode_bs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(alaw_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.alaw_decode_bs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(alaw_decode_bs_sptr self, long max_output_buffer)
        set_max_output_buffer(alaw_decode_bs_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.alaw_decode_bs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(alaw_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.alaw_decode_bs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(alaw_decode_bs_sptr self, long min_output_buffer)
        set_min_output_buffer(alaw_decode_bs_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.alaw_decode_bs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(alaw_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full(alaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_decode_bs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(alaw_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_avg(alaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_decode_bs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(alaw_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_var(alaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_decode_bs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(alaw_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full(alaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_decode_bs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(alaw_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_avg(alaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_decode_bs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(alaw_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_var(alaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_decode_bs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(alaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.alaw_decode_bs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(alaw_decode_bs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(alaw_decode_bs_sptr self)"""
        return _vocoder_swig.alaw_decode_bs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(alaw_decode_bs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.alaw_decode_bs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(alaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.alaw_decode_bs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(alaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.alaw_decode_bs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(alaw_decode_bs_sptr self, int priority) -> int"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(alaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.alaw_decode_bs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(alaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.alaw_decode_bs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(alaw_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(alaw_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(alaw_decode_bs_sptr self) -> long"""
        return _vocoder_swig.alaw_decode_bs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(alaw_decode_bs_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(alaw_decode_bs_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.alaw_decode_bs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(alaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.alaw_decode_bs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(alaw_decode_bs_sptr self, std::string name)"""
        return _vocoder_swig.alaw_decode_bs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(alaw_decode_bs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.alaw_decode_bs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(alaw_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(alaw_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(alaw_decode_bs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.alaw_decode_bs_sptr_message_subscribers(self, which_port)

# Register alaw_decode_bs_sptr in _vocoder_swig:
_vocoder_swig.alaw_decode_bs_sptr_swigregister(alaw_decode_bs_sptr)


alaw_decode_bs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
alaw_decode_bs = alaw_decode_bs.make;

class alaw_encode_sb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::alaw_encode_sb > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(alaw_encode_sb_sptr self) -> alaw_encode_sb_sptr
        __init__(alaw_encode_sb_sptr self, alaw_encode_sb p) -> alaw_encode_sb_sptr
        """
        _vocoder_swig.alaw_encode_sb_sptr_swiginit(self, _vocoder_swig.new_alaw_encode_sb_sptr(*args))

    def __deref__(self) -> "gr::vocoder::alaw_encode_sb *":
        r"""__deref__(alaw_encode_sb_sptr self) -> alaw_encode_sb"""
        return _vocoder_swig.alaw_encode_sb_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_alaw_encode_sb_sptr

    def make(self) -> "gr::vocoder::alaw_encode_sb::sptr":
        r"""make(alaw_encode_sb_sptr self) -> alaw_encode_sb_sptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(alaw_encode_sb_sptr self) -> unsigned int"""
        return _vocoder_swig.alaw_encode_sb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(alaw_encode_sb_sptr self, int which, int delay)
        declare_sample_delay(alaw_encode_sb_sptr self, unsigned int delay)
        """
        return _vocoder_swig.alaw_encode_sb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(alaw_encode_sb_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.alaw_encode_sb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(alaw_encode_sb_sptr self, int multiple)"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(alaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.alaw_encode_sb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(alaw_encode_sb_sptr self) -> double"""
        return _vocoder_swig.alaw_encode_sb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(alaw_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.alaw_encode_sb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(alaw_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.alaw_encode_sb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(alaw_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.alaw_encode_sb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(alaw_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.alaw_encode_sb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(alaw_encode_sb_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.alaw_encode_sb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(alaw_encode_sb_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.alaw_encode_sb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(alaw_encode_sb_sptr self, std::string level)"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(alaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.alaw_encode_sb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(alaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.alaw_encode_sb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(alaw_encode_sb_sptr self, int m)"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(alaw_encode_sb_sptr self)"""
        return _vocoder_swig.alaw_encode_sb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(alaw_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.alaw_encode_sb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(alaw_encode_sb_sptr self, int m)"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(alaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.alaw_encode_sb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(alaw_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.alaw_encode_sb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(alaw_encode_sb_sptr self, long max_output_buffer)
        set_max_output_buffer(alaw_encode_sb_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.alaw_encode_sb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(alaw_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.alaw_encode_sb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(alaw_encode_sb_sptr self, long min_output_buffer)
        set_min_output_buffer(alaw_encode_sb_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.alaw_encode_sb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(alaw_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full(alaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_encode_sb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(alaw_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_avg(alaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_encode_sb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(alaw_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_var(alaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_encode_sb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(alaw_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full(alaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_encode_sb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(alaw_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_avg(alaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_encode_sb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(alaw_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_var(alaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.alaw_encode_sb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(alaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.alaw_encode_sb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(alaw_encode_sb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(alaw_encode_sb_sptr self)"""
        return _vocoder_swig.alaw_encode_sb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(alaw_encode_sb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.alaw_encode_sb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(alaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.alaw_encode_sb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(alaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.alaw_encode_sb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(alaw_encode_sb_sptr self, int priority) -> int"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(alaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.alaw_encode_sb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(alaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.alaw_encode_sb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(alaw_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(alaw_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(alaw_encode_sb_sptr self) -> long"""
        return _vocoder_swig.alaw_encode_sb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(alaw_encode_sb_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(alaw_encode_sb_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.alaw_encode_sb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(alaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.alaw_encode_sb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(alaw_encode_sb_sptr self, std::string name)"""
        return _vocoder_swig.alaw_encode_sb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(alaw_encode_sb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.alaw_encode_sb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(alaw_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(alaw_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(alaw_encode_sb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.alaw_encode_sb_sptr_message_subscribers(self, which_port)

# Register alaw_encode_sb_sptr in _vocoder_swig:
_vocoder_swig.alaw_encode_sb_sptr_swigregister(alaw_encode_sb_sptr)


alaw_encode_sb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
alaw_encode_sb = alaw_encode_sb.make;

class cvsd_decode_bs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::cvsd_decode_bs > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(cvsd_decode_bs_sptr self) -> cvsd_decode_bs_sptr
        __init__(cvsd_decode_bs_sptr self, cvsd_decode_bs p) -> cvsd_decode_bs_sptr
        """
        _vocoder_swig.cvsd_decode_bs_sptr_swiginit(self, _vocoder_swig.new_cvsd_decode_bs_sptr(*args))

    def __deref__(self) -> "gr::vocoder::cvsd_decode_bs *":
        r"""__deref__(cvsd_decode_bs_sptr self) -> cvsd_decode_bs"""
        return _vocoder_swig.cvsd_decode_bs_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_cvsd_decode_bs_sptr

    def make(self, min_step: "short"=10, max_step: "short"=1280, step_decay: "double"=0.9990234375, accum_decay: "double"=0.96875, K: "int"=32, J: "int"=4, pos_accum_max: "short"=32767, neg_accum_max: "short"=-32767) -> "gr::vocoder::cvsd_decode_bs::sptr":
        r"""make(cvsd_decode_bs_sptr self, short min_step=10, short max_step=1280, double step_decay=0.9990234375, double accum_decay=0.96875, int K=32, int J=4, short pos_accum_max=32767, short neg_accum_max=-32767) -> cvsd_decode_bs_sptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_make(self, min_step, max_step, step_decay, accum_decay, K, J, pos_accum_max, neg_accum_max)

    def min_step(self) -> "short":
        r"""min_step(cvsd_decode_bs_sptr self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_sptr_min_step(self)

    def max_step(self) -> "short":
        r"""max_step(cvsd_decode_bs_sptr self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_sptr_max_step(self)

    def step_decay(self) -> "double":
        r"""step_decay(cvsd_decode_bs_sptr self) -> double"""
        return _vocoder_swig.cvsd_decode_bs_sptr_step_decay(self)

    def accum_decay(self) -> "double":
        r"""accum_decay(cvsd_decode_bs_sptr self) -> double"""
        return _vocoder_swig.cvsd_decode_bs_sptr_accum_decay(self)

    def K(self) -> "int":
        r"""K(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_K(self)

    def J(self) -> "int":
        r"""J(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_J(self)

    def pos_accum_max(self) -> "short":
        r"""pos_accum_max(cvsd_decode_bs_sptr self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pos_accum_max(self)

    def neg_accum_max(self) -> "short":
        r"""neg_accum_max(cvsd_decode_bs_sptr self) -> short"""
        return _vocoder_swig.cvsd_decode_bs_sptr_neg_accum_max(self)

    def history(self) -> "unsigned int":
        r"""history(cvsd_decode_bs_sptr self) -> unsigned int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(cvsd_decode_bs_sptr self, int which, int delay)
        declare_sample_delay(cvsd_decode_bs_sptr self, unsigned int delay)
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(cvsd_decode_bs_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(cvsd_decode_bs_sptr self, int multiple)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(cvsd_decode_bs_sptr self) -> double"""
        return _vocoder_swig.cvsd_decode_bs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(cvsd_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.cvsd_decode_bs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(cvsd_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.cvsd_decode_bs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(cvsd_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.cvsd_decode_bs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(cvsd_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.cvsd_decode_bs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(cvsd_decode_bs_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.cvsd_decode_bs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(cvsd_decode_bs_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.cvsd_decode_bs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(cvsd_decode_bs_sptr self, std::string level)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(cvsd_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_decode_bs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(cvsd_decode_bs_sptr self, int m)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(cvsd_decode_bs_sptr self)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(cvsd_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.cvsd_decode_bs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(cvsd_decode_bs_sptr self, int m)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(cvsd_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.cvsd_decode_bs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(cvsd_decode_bs_sptr self, long max_output_buffer)
        set_max_output_buffer(cvsd_decode_bs_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(cvsd_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.cvsd_decode_bs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(cvsd_decode_bs_sptr self, long min_output_buffer)
        set_min_output_buffer(cvsd_decode_bs_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(cvsd_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full(cvsd_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(cvsd_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_avg(cvsd_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(cvsd_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_var(cvsd_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(cvsd_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full(cvsd_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(cvsd_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_avg(cvsd_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(cvsd_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_var(cvsd_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(cvsd_decode_bs_sptr self) -> float"""
        return _vocoder_swig.cvsd_decode_bs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(cvsd_decode_bs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(cvsd_decode_bs_sptr self)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(cvsd_decode_bs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.cvsd_decode_bs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(cvsd_decode_bs_sptr self) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(cvsd_decode_bs_sptr self, int priority) -> int"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(cvsd_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_decode_bs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(cvsd_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_decode_bs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(cvsd_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(cvsd_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(cvsd_decode_bs_sptr self) -> long"""
        return _vocoder_swig.cvsd_decode_bs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(cvsd_decode_bs_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(cvsd_decode_bs_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.cvsd_decode_bs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(cvsd_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_decode_bs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(cvsd_decode_bs_sptr self, std::string name)"""
        return _vocoder_swig.cvsd_decode_bs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(cvsd_decode_bs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.cvsd_decode_bs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(cvsd_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(cvsd_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(cvsd_decode_bs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.cvsd_decode_bs_sptr_message_subscribers(self, which_port)

# Register cvsd_decode_bs_sptr in _vocoder_swig:
_vocoder_swig.cvsd_decode_bs_sptr_swigregister(cvsd_decode_bs_sptr)


cvsd_decode_bs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
cvsd_decode_bs = cvsd_decode_bs.make;

class cvsd_encode_sb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::cvsd_encode_sb > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(cvsd_encode_sb_sptr self) -> cvsd_encode_sb_sptr
        __init__(cvsd_encode_sb_sptr self, cvsd_encode_sb p) -> cvsd_encode_sb_sptr
        """
        _vocoder_swig.cvsd_encode_sb_sptr_swiginit(self, _vocoder_swig.new_cvsd_encode_sb_sptr(*args))

    def __deref__(self) -> "gr::vocoder::cvsd_encode_sb *":
        r"""__deref__(cvsd_encode_sb_sptr self) -> cvsd_encode_sb"""
        return _vocoder_swig.cvsd_encode_sb_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_cvsd_encode_sb_sptr

    def make(self, min_step: "short"=10, max_step: "short"=1280, step_decay: "double"=0.9990234375, accum_decay: "double"=0.96875, K: "int"=32, J: "int"=4, pos_accum_max: "short"=32767, neg_accum_max: "short"=-32767) -> "gr::vocoder::cvsd_encode_sb::sptr":
        r"""make(cvsd_encode_sb_sptr self, short min_step=10, short max_step=1280, double step_decay=0.9990234375, double accum_decay=0.96875, int K=32, int J=4, short pos_accum_max=32767, short neg_accum_max=-32767) -> cvsd_encode_sb_sptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_make(self, min_step, max_step, step_decay, accum_decay, K, J, pos_accum_max, neg_accum_max)

    def min_step(self) -> "short":
        r"""min_step(cvsd_encode_sb_sptr self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_sptr_min_step(self)

    def max_step(self) -> "short":
        r"""max_step(cvsd_encode_sb_sptr self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_sptr_max_step(self)

    def step_decay(self) -> "double":
        r"""step_decay(cvsd_encode_sb_sptr self) -> double"""
        return _vocoder_swig.cvsd_encode_sb_sptr_step_decay(self)

    def accum_decay(self) -> "double":
        r"""accum_decay(cvsd_encode_sb_sptr self) -> double"""
        return _vocoder_swig.cvsd_encode_sb_sptr_accum_decay(self)

    def K(self) -> "int":
        r"""K(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_K(self)

    def J(self) -> "int":
        r"""J(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_J(self)

    def pos_accum_max(self) -> "short":
        r"""pos_accum_max(cvsd_encode_sb_sptr self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pos_accum_max(self)

    def neg_accum_max(self) -> "short":
        r"""neg_accum_max(cvsd_encode_sb_sptr self) -> short"""
        return _vocoder_swig.cvsd_encode_sb_sptr_neg_accum_max(self)

    def history(self) -> "unsigned int":
        r"""history(cvsd_encode_sb_sptr self) -> unsigned int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(cvsd_encode_sb_sptr self, int which, int delay)
        declare_sample_delay(cvsd_encode_sb_sptr self, unsigned int delay)
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(cvsd_encode_sb_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(cvsd_encode_sb_sptr self, int multiple)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(cvsd_encode_sb_sptr self) -> double"""
        return _vocoder_swig.cvsd_encode_sb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(cvsd_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.cvsd_encode_sb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(cvsd_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.cvsd_encode_sb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(cvsd_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.cvsd_encode_sb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(cvsd_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.cvsd_encode_sb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(cvsd_encode_sb_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.cvsd_encode_sb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(cvsd_encode_sb_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.cvsd_encode_sb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(cvsd_encode_sb_sptr self, std::string level)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(cvsd_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_encode_sb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(cvsd_encode_sb_sptr self, int m)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(cvsd_encode_sb_sptr self)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(cvsd_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.cvsd_encode_sb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(cvsd_encode_sb_sptr self, int m)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(cvsd_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.cvsd_encode_sb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(cvsd_encode_sb_sptr self, long max_output_buffer)
        set_max_output_buffer(cvsd_encode_sb_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(cvsd_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.cvsd_encode_sb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(cvsd_encode_sb_sptr self, long min_output_buffer)
        set_min_output_buffer(cvsd_encode_sb_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(cvsd_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full(cvsd_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(cvsd_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_avg(cvsd_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(cvsd_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_var(cvsd_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(cvsd_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full(cvsd_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(cvsd_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_avg(cvsd_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(cvsd_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_var(cvsd_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(cvsd_encode_sb_sptr self) -> float"""
        return _vocoder_swig.cvsd_encode_sb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(cvsd_encode_sb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(cvsd_encode_sb_sptr self)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(cvsd_encode_sb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.cvsd_encode_sb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(cvsd_encode_sb_sptr self) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(cvsd_encode_sb_sptr self, int priority) -> int"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(cvsd_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_encode_sb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(cvsd_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_encode_sb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(cvsd_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(cvsd_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(cvsd_encode_sb_sptr self) -> long"""
        return _vocoder_swig.cvsd_encode_sb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(cvsd_encode_sb_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(cvsd_encode_sb_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.cvsd_encode_sb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(cvsd_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.cvsd_encode_sb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(cvsd_encode_sb_sptr self, std::string name)"""
        return _vocoder_swig.cvsd_encode_sb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(cvsd_encode_sb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.cvsd_encode_sb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(cvsd_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(cvsd_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(cvsd_encode_sb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.cvsd_encode_sb_sptr_message_subscribers(self, which_port)

# Register cvsd_encode_sb_sptr in _vocoder_swig:
_vocoder_swig.cvsd_encode_sb_sptr_swigregister(cvsd_encode_sb_sptr)


cvsd_encode_sb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
cvsd_encode_sb = cvsd_encode_sb.make;

class g721_decode_bs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::g721_decode_bs > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(g721_decode_bs_sptr self) -> g721_decode_bs_sptr
        __init__(g721_decode_bs_sptr self, g721_decode_bs p) -> g721_decode_bs_sptr
        """
        _vocoder_swig.g721_decode_bs_sptr_swiginit(self, _vocoder_swig.new_g721_decode_bs_sptr(*args))

    def __deref__(self) -> "gr::vocoder::g721_decode_bs *":
        r"""__deref__(g721_decode_bs_sptr self) -> g721_decode_bs"""
        return _vocoder_swig.g721_decode_bs_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_g721_decode_bs_sptr

    def make(self) -> "gr::vocoder::g721_decode_bs::sptr":
        r"""make(g721_decode_bs_sptr self) -> g721_decode_bs_sptr"""
        return _vocoder_swig.g721_decode_bs_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(g721_decode_bs_sptr self) -> unsigned int"""
        return _vocoder_swig.g721_decode_bs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(g721_decode_bs_sptr self, int which, int delay)
        declare_sample_delay(g721_decode_bs_sptr self, unsigned int delay)
        """
        return _vocoder_swig.g721_decode_bs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(g721_decode_bs_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.g721_decode_bs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(g721_decode_bs_sptr self, int multiple)"""
        return _vocoder_swig.g721_decode_bs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(g721_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g721_decode_bs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(g721_decode_bs_sptr self) -> double"""
        return _vocoder_swig.g721_decode_bs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(g721_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.g721_decode_bs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(g721_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.g721_decode_bs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(g721_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g721_decode_bs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(g721_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g721_decode_bs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(g721_decode_bs_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.g721_decode_bs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(g721_decode_bs_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.g721_decode_bs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(g721_decode_bs_sptr self, std::string level)"""
        return _vocoder_swig.g721_decode_bs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(g721_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g721_decode_bs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(g721_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g721_decode_bs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(g721_decode_bs_sptr self, int m)"""
        return _vocoder_swig.g721_decode_bs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(g721_decode_bs_sptr self)"""
        return _vocoder_swig.g721_decode_bs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(g721_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g721_decode_bs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(g721_decode_bs_sptr self, int m)"""
        return _vocoder_swig.g721_decode_bs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(g721_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g721_decode_bs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(g721_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.g721_decode_bs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(g721_decode_bs_sptr self, long max_output_buffer)
        set_max_output_buffer(g721_decode_bs_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.g721_decode_bs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(g721_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.g721_decode_bs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(g721_decode_bs_sptr self, long min_output_buffer)
        set_min_output_buffer(g721_decode_bs_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.g721_decode_bs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(g721_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full(g721_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_decode_bs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(g721_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_avg(g721_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_decode_bs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(g721_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_var(g721_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_decode_bs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(g721_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full(g721_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_decode_bs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(g721_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_avg(g721_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_decode_bs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(g721_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_var(g721_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_decode_bs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(g721_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g721_decode_bs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(g721_decode_bs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.g721_decode_bs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(g721_decode_bs_sptr self)"""
        return _vocoder_swig.g721_decode_bs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(g721_decode_bs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.g721_decode_bs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(g721_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g721_decode_bs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(g721_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g721_decode_bs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(g721_decode_bs_sptr self, int priority) -> int"""
        return _vocoder_swig.g721_decode_bs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(g721_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g721_decode_bs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(g721_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g721_decode_bs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(g721_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g721_decode_bs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(g721_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g721_decode_bs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(g721_decode_bs_sptr self) -> long"""
        return _vocoder_swig.g721_decode_bs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(g721_decode_bs_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.g721_decode_bs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(g721_decode_bs_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.g721_decode_bs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(g721_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g721_decode_bs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(g721_decode_bs_sptr self, std::string name)"""
        return _vocoder_swig.g721_decode_bs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(g721_decode_bs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.g721_decode_bs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(g721_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g721_decode_bs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(g721_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g721_decode_bs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(g721_decode_bs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.g721_decode_bs_sptr_message_subscribers(self, which_port)

# Register g721_decode_bs_sptr in _vocoder_swig:
_vocoder_swig.g721_decode_bs_sptr_swigregister(g721_decode_bs_sptr)


g721_decode_bs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
g721_decode_bs = g721_decode_bs.make;

class g721_encode_sb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::g721_encode_sb > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(g721_encode_sb_sptr self) -> g721_encode_sb_sptr
        __init__(g721_encode_sb_sptr self, g721_encode_sb p) -> g721_encode_sb_sptr
        """
        _vocoder_swig.g721_encode_sb_sptr_swiginit(self, _vocoder_swig.new_g721_encode_sb_sptr(*args))

    def __deref__(self) -> "gr::vocoder::g721_encode_sb *":
        r"""__deref__(g721_encode_sb_sptr self) -> g721_encode_sb"""
        return _vocoder_swig.g721_encode_sb_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_g721_encode_sb_sptr

    def make(self) -> "gr::vocoder::g721_encode_sb::sptr":
        r"""make(g721_encode_sb_sptr self) -> g721_encode_sb_sptr"""
        return _vocoder_swig.g721_encode_sb_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(g721_encode_sb_sptr self) -> unsigned int"""
        return _vocoder_swig.g721_encode_sb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(g721_encode_sb_sptr self, int which, int delay)
        declare_sample_delay(g721_encode_sb_sptr self, unsigned int delay)
        """
        return _vocoder_swig.g721_encode_sb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(g721_encode_sb_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.g721_encode_sb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(g721_encode_sb_sptr self, int multiple)"""
        return _vocoder_swig.g721_encode_sb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(g721_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g721_encode_sb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(g721_encode_sb_sptr self) -> double"""
        return _vocoder_swig.g721_encode_sb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(g721_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.g721_encode_sb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(g721_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.g721_encode_sb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(g721_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g721_encode_sb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(g721_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g721_encode_sb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(g721_encode_sb_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.g721_encode_sb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(g721_encode_sb_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.g721_encode_sb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(g721_encode_sb_sptr self, std::string level)"""
        return _vocoder_swig.g721_encode_sb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(g721_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g721_encode_sb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(g721_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g721_encode_sb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(g721_encode_sb_sptr self, int m)"""
        return _vocoder_swig.g721_encode_sb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(g721_encode_sb_sptr self)"""
        return _vocoder_swig.g721_encode_sb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(g721_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g721_encode_sb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(g721_encode_sb_sptr self, int m)"""
        return _vocoder_swig.g721_encode_sb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(g721_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g721_encode_sb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(g721_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.g721_encode_sb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(g721_encode_sb_sptr self, long max_output_buffer)
        set_max_output_buffer(g721_encode_sb_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.g721_encode_sb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(g721_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.g721_encode_sb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(g721_encode_sb_sptr self, long min_output_buffer)
        set_min_output_buffer(g721_encode_sb_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.g721_encode_sb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(g721_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full(g721_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_encode_sb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(g721_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_avg(g721_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_encode_sb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(g721_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_var(g721_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_encode_sb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(g721_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full(g721_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_encode_sb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(g721_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_avg(g721_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_encode_sb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(g721_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_var(g721_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g721_encode_sb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(g721_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g721_encode_sb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(g721_encode_sb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.g721_encode_sb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(g721_encode_sb_sptr self)"""
        return _vocoder_swig.g721_encode_sb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(g721_encode_sb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.g721_encode_sb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(g721_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g721_encode_sb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(g721_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g721_encode_sb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(g721_encode_sb_sptr self, int priority) -> int"""
        return _vocoder_swig.g721_encode_sb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(g721_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g721_encode_sb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(g721_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g721_encode_sb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(g721_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g721_encode_sb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(g721_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g721_encode_sb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(g721_encode_sb_sptr self) -> long"""
        return _vocoder_swig.g721_encode_sb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(g721_encode_sb_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.g721_encode_sb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(g721_encode_sb_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.g721_encode_sb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(g721_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g721_encode_sb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(g721_encode_sb_sptr self, std::string name)"""
        return _vocoder_swig.g721_encode_sb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(g721_encode_sb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.g721_encode_sb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(g721_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g721_encode_sb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(g721_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g721_encode_sb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(g721_encode_sb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.g721_encode_sb_sptr_message_subscribers(self, which_port)

# Register g721_encode_sb_sptr in _vocoder_swig:
_vocoder_swig.g721_encode_sb_sptr_swigregister(g721_encode_sb_sptr)


g721_encode_sb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
g721_encode_sb = g721_encode_sb.make;

class g723_24_decode_bs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::g723_24_decode_bs > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(g723_24_decode_bs_sptr self) -> g723_24_decode_bs_sptr
        __init__(g723_24_decode_bs_sptr self, g723_24_decode_bs p) -> g723_24_decode_bs_sptr
        """
        _vocoder_swig.g723_24_decode_bs_sptr_swiginit(self, _vocoder_swig.new_g723_24_decode_bs_sptr(*args))

    def __deref__(self) -> "gr::vocoder::g723_24_decode_bs *":
        r"""__deref__(g723_24_decode_bs_sptr self) -> g723_24_decode_bs"""
        return _vocoder_swig.g723_24_decode_bs_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_g723_24_decode_bs_sptr

    def make(self) -> "gr::vocoder::g723_24_decode_bs::sptr":
        r"""make(g723_24_decode_bs_sptr self) -> g723_24_decode_bs_sptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(g723_24_decode_bs_sptr self) -> unsigned int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(g723_24_decode_bs_sptr self, int which, int delay)
        declare_sample_delay(g723_24_decode_bs_sptr self, unsigned int delay)
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(g723_24_decode_bs_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(g723_24_decode_bs_sptr self, int multiple)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(g723_24_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(g723_24_decode_bs_sptr self) -> double"""
        return _vocoder_swig.g723_24_decode_bs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(g723_24_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_24_decode_bs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(g723_24_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_24_decode_bs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(g723_24_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g723_24_decode_bs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(g723_24_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g723_24_decode_bs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(g723_24_decode_bs_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.g723_24_decode_bs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(g723_24_decode_bs_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.g723_24_decode_bs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(g723_24_decode_bs_sptr self, std::string level)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(g723_24_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_decode_bs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(g723_24_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(g723_24_decode_bs_sptr self, int m)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(g723_24_decode_bs_sptr self)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(g723_24_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g723_24_decode_bs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(g723_24_decode_bs_sptr self, int m)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(g723_24_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(g723_24_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.g723_24_decode_bs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(g723_24_decode_bs_sptr self, long max_output_buffer)
        set_max_output_buffer(g723_24_decode_bs_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(g723_24_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.g723_24_decode_bs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(g723_24_decode_bs_sptr self, long min_output_buffer)
        set_min_output_buffer(g723_24_decode_bs_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(g723_24_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full(g723_24_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(g723_24_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_avg(g723_24_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(g723_24_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_var(g723_24_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(g723_24_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full(g723_24_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(g723_24_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_avg(g723_24_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(g723_24_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_var(g723_24_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(g723_24_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_24_decode_bs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(g723_24_decode_bs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(g723_24_decode_bs_sptr self)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(g723_24_decode_bs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.g723_24_decode_bs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(g723_24_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(g723_24_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(g723_24_decode_bs_sptr self, int priority) -> int"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(g723_24_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_decode_bs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(g723_24_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_decode_bs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(g723_24_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(g723_24_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(g723_24_decode_bs_sptr self) -> long"""
        return _vocoder_swig.g723_24_decode_bs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(g723_24_decode_bs_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(g723_24_decode_bs_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.g723_24_decode_bs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(g723_24_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_decode_bs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(g723_24_decode_bs_sptr self, std::string name)"""
        return _vocoder_swig.g723_24_decode_bs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(g723_24_decode_bs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.g723_24_decode_bs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(g723_24_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(g723_24_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(g723_24_decode_bs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_24_decode_bs_sptr_message_subscribers(self, which_port)

# Register g723_24_decode_bs_sptr in _vocoder_swig:
_vocoder_swig.g723_24_decode_bs_sptr_swigregister(g723_24_decode_bs_sptr)


g723_24_decode_bs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
g723_24_decode_bs = g723_24_decode_bs.make;

class g723_24_encode_sb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::g723_24_encode_sb > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(g723_24_encode_sb_sptr self) -> g723_24_encode_sb_sptr
        __init__(g723_24_encode_sb_sptr self, g723_24_encode_sb p) -> g723_24_encode_sb_sptr
        """
        _vocoder_swig.g723_24_encode_sb_sptr_swiginit(self, _vocoder_swig.new_g723_24_encode_sb_sptr(*args))

    def __deref__(self) -> "gr::vocoder::g723_24_encode_sb *":
        r"""__deref__(g723_24_encode_sb_sptr self) -> g723_24_encode_sb"""
        return _vocoder_swig.g723_24_encode_sb_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_g723_24_encode_sb_sptr

    def make(self) -> "gr::vocoder::g723_24_encode_sb::sptr":
        r"""make(g723_24_encode_sb_sptr self) -> g723_24_encode_sb_sptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(g723_24_encode_sb_sptr self) -> unsigned int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(g723_24_encode_sb_sptr self, int which, int delay)
        declare_sample_delay(g723_24_encode_sb_sptr self, unsigned int delay)
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(g723_24_encode_sb_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(g723_24_encode_sb_sptr self, int multiple)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(g723_24_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(g723_24_encode_sb_sptr self) -> double"""
        return _vocoder_swig.g723_24_encode_sb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(g723_24_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_24_encode_sb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(g723_24_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_24_encode_sb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(g723_24_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g723_24_encode_sb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(g723_24_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g723_24_encode_sb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(g723_24_encode_sb_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.g723_24_encode_sb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(g723_24_encode_sb_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.g723_24_encode_sb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(g723_24_encode_sb_sptr self, std::string level)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(g723_24_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_encode_sb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(g723_24_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(g723_24_encode_sb_sptr self, int m)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(g723_24_encode_sb_sptr self)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(g723_24_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g723_24_encode_sb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(g723_24_encode_sb_sptr self, int m)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(g723_24_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(g723_24_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.g723_24_encode_sb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(g723_24_encode_sb_sptr self, long max_output_buffer)
        set_max_output_buffer(g723_24_encode_sb_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(g723_24_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.g723_24_encode_sb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(g723_24_encode_sb_sptr self, long min_output_buffer)
        set_min_output_buffer(g723_24_encode_sb_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(g723_24_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full(g723_24_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(g723_24_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_avg(g723_24_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(g723_24_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_var(g723_24_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(g723_24_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full(g723_24_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(g723_24_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_avg(g723_24_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(g723_24_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_var(g723_24_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(g723_24_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_24_encode_sb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(g723_24_encode_sb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(g723_24_encode_sb_sptr self)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(g723_24_encode_sb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.g723_24_encode_sb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(g723_24_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(g723_24_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(g723_24_encode_sb_sptr self, int priority) -> int"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(g723_24_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_encode_sb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(g723_24_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_encode_sb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(g723_24_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(g723_24_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(g723_24_encode_sb_sptr self) -> long"""
        return _vocoder_swig.g723_24_encode_sb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(g723_24_encode_sb_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(g723_24_encode_sb_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.g723_24_encode_sb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(g723_24_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_24_encode_sb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(g723_24_encode_sb_sptr self, std::string name)"""
        return _vocoder_swig.g723_24_encode_sb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(g723_24_encode_sb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.g723_24_encode_sb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(g723_24_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(g723_24_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(g723_24_encode_sb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_24_encode_sb_sptr_message_subscribers(self, which_port)

# Register g723_24_encode_sb_sptr in _vocoder_swig:
_vocoder_swig.g723_24_encode_sb_sptr_swigregister(g723_24_encode_sb_sptr)


g723_24_encode_sb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
g723_24_encode_sb = g723_24_encode_sb.make;

class g723_40_decode_bs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::g723_40_decode_bs > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(g723_40_decode_bs_sptr self) -> g723_40_decode_bs_sptr
        __init__(g723_40_decode_bs_sptr self, g723_40_decode_bs p) -> g723_40_decode_bs_sptr
        """
        _vocoder_swig.g723_40_decode_bs_sptr_swiginit(self, _vocoder_swig.new_g723_40_decode_bs_sptr(*args))

    def __deref__(self) -> "gr::vocoder::g723_40_decode_bs *":
        r"""__deref__(g723_40_decode_bs_sptr self) -> g723_40_decode_bs"""
        return _vocoder_swig.g723_40_decode_bs_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_g723_40_decode_bs_sptr

    def make(self) -> "gr::vocoder::g723_40_decode_bs::sptr":
        r"""make(g723_40_decode_bs_sptr self) -> g723_40_decode_bs_sptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(g723_40_decode_bs_sptr self) -> unsigned int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(g723_40_decode_bs_sptr self, int which, int delay)
        declare_sample_delay(g723_40_decode_bs_sptr self, unsigned int delay)
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(g723_40_decode_bs_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(g723_40_decode_bs_sptr self, int multiple)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(g723_40_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(g723_40_decode_bs_sptr self) -> double"""
        return _vocoder_swig.g723_40_decode_bs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(g723_40_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_40_decode_bs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(g723_40_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_40_decode_bs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(g723_40_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g723_40_decode_bs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(g723_40_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g723_40_decode_bs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(g723_40_decode_bs_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.g723_40_decode_bs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(g723_40_decode_bs_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.g723_40_decode_bs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(g723_40_decode_bs_sptr self, std::string level)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(g723_40_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_decode_bs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(g723_40_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(g723_40_decode_bs_sptr self, int m)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(g723_40_decode_bs_sptr self)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(g723_40_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.g723_40_decode_bs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(g723_40_decode_bs_sptr self, int m)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(g723_40_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(g723_40_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.g723_40_decode_bs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(g723_40_decode_bs_sptr self, long max_output_buffer)
        set_max_output_buffer(g723_40_decode_bs_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(g723_40_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.g723_40_decode_bs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(g723_40_decode_bs_sptr self, long min_output_buffer)
        set_min_output_buffer(g723_40_decode_bs_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(g723_40_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full(g723_40_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(g723_40_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_avg(g723_40_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(g723_40_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_var(g723_40_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(g723_40_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full(g723_40_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(g723_40_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_avg(g723_40_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(g723_40_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_var(g723_40_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(g723_40_decode_bs_sptr self) -> float"""
        return _vocoder_swig.g723_40_decode_bs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(g723_40_decode_bs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(g723_40_decode_bs_sptr self)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(g723_40_decode_bs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.g723_40_decode_bs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(g723_40_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(g723_40_decode_bs_sptr self) -> int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(g723_40_decode_bs_sptr self, int priority) -> int"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(g723_40_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_decode_bs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(g723_40_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_decode_bs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(g723_40_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(g723_40_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(g723_40_decode_bs_sptr self) -> long"""
        return _vocoder_swig.g723_40_decode_bs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(g723_40_decode_bs_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(g723_40_decode_bs_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.g723_40_decode_bs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(g723_40_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_decode_bs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(g723_40_decode_bs_sptr self, std::string name)"""
        return _vocoder_swig.g723_40_decode_bs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(g723_40_decode_bs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.g723_40_decode_bs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(g723_40_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(g723_40_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(g723_40_decode_bs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_40_decode_bs_sptr_message_subscribers(self, which_port)

# Register g723_40_decode_bs_sptr in _vocoder_swig:
_vocoder_swig.g723_40_decode_bs_sptr_swigregister(g723_40_decode_bs_sptr)


g723_40_decode_bs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
g723_40_decode_bs = g723_40_decode_bs.make;

class g723_40_encode_sb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::g723_40_encode_sb > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(g723_40_encode_sb_sptr self) -> g723_40_encode_sb_sptr
        __init__(g723_40_encode_sb_sptr self, g723_40_encode_sb p) -> g723_40_encode_sb_sptr
        """
        _vocoder_swig.g723_40_encode_sb_sptr_swiginit(self, _vocoder_swig.new_g723_40_encode_sb_sptr(*args))

    def __deref__(self) -> "gr::vocoder::g723_40_encode_sb *":
        r"""__deref__(g723_40_encode_sb_sptr self) -> g723_40_encode_sb"""
        return _vocoder_swig.g723_40_encode_sb_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_g723_40_encode_sb_sptr

    def make(self) -> "gr::vocoder::g723_40_encode_sb::sptr":
        r"""make(g723_40_encode_sb_sptr self) -> g723_40_encode_sb_sptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(g723_40_encode_sb_sptr self) -> unsigned int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(g723_40_encode_sb_sptr self, int which, int delay)
        declare_sample_delay(g723_40_encode_sb_sptr self, unsigned int delay)
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(g723_40_encode_sb_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(g723_40_encode_sb_sptr self, int multiple)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(g723_40_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(g723_40_encode_sb_sptr self) -> double"""
        return _vocoder_swig.g723_40_encode_sb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(g723_40_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_40_encode_sb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(g723_40_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.g723_40_encode_sb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(g723_40_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g723_40_encode_sb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(g723_40_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g723_40_encode_sb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(g723_40_encode_sb_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.g723_40_encode_sb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(g723_40_encode_sb_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.g723_40_encode_sb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(g723_40_encode_sb_sptr self, std::string level)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(g723_40_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_encode_sb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(g723_40_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(g723_40_encode_sb_sptr self, int m)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(g723_40_encode_sb_sptr self)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(g723_40_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.g723_40_encode_sb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(g723_40_encode_sb_sptr self, int m)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(g723_40_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(g723_40_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.g723_40_encode_sb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(g723_40_encode_sb_sptr self, long max_output_buffer)
        set_max_output_buffer(g723_40_encode_sb_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(g723_40_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.g723_40_encode_sb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(g723_40_encode_sb_sptr self, long min_output_buffer)
        set_min_output_buffer(g723_40_encode_sb_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(g723_40_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full(g723_40_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(g723_40_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_avg(g723_40_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(g723_40_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_var(g723_40_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(g723_40_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full(g723_40_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(g723_40_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_avg(g723_40_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(g723_40_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_var(g723_40_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(g723_40_encode_sb_sptr self) -> float"""
        return _vocoder_swig.g723_40_encode_sb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(g723_40_encode_sb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(g723_40_encode_sb_sptr self)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(g723_40_encode_sb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.g723_40_encode_sb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(g723_40_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(g723_40_encode_sb_sptr self) -> int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(g723_40_encode_sb_sptr self, int priority) -> int"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(g723_40_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_encode_sb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(g723_40_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_encode_sb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(g723_40_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(g723_40_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(g723_40_encode_sb_sptr self) -> long"""
        return _vocoder_swig.g723_40_encode_sb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(g723_40_encode_sb_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(g723_40_encode_sb_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.g723_40_encode_sb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(g723_40_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.g723_40_encode_sb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(g723_40_encode_sb_sptr self, std::string name)"""
        return _vocoder_swig.g723_40_encode_sb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(g723_40_encode_sb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.g723_40_encode_sb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(g723_40_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(g723_40_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(g723_40_encode_sb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.g723_40_encode_sb_sptr_message_subscribers(self, which_port)

# Register g723_40_encode_sb_sptr in _vocoder_swig:
_vocoder_swig.g723_40_encode_sb_sptr_swigregister(g723_40_encode_sb_sptr)


g723_40_encode_sb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
g723_40_encode_sb = g723_40_encode_sb.make;

class ulaw_decode_bs_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::ulaw_decode_bs > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(ulaw_decode_bs_sptr self) -> ulaw_decode_bs_sptr
        __init__(ulaw_decode_bs_sptr self, ulaw_decode_bs p) -> ulaw_decode_bs_sptr
        """
        _vocoder_swig.ulaw_decode_bs_sptr_swiginit(self, _vocoder_swig.new_ulaw_decode_bs_sptr(*args))

    def __deref__(self) -> "gr::vocoder::ulaw_decode_bs *":
        r"""__deref__(ulaw_decode_bs_sptr self) -> ulaw_decode_bs"""
        return _vocoder_swig.ulaw_decode_bs_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_ulaw_decode_bs_sptr

    def make(self) -> "gr::vocoder::ulaw_decode_bs::sptr":
        r"""make(ulaw_decode_bs_sptr self) -> ulaw_decode_bs_sptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(ulaw_decode_bs_sptr self) -> unsigned int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(ulaw_decode_bs_sptr self, int which, int delay)
        declare_sample_delay(ulaw_decode_bs_sptr self, unsigned int delay)
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(ulaw_decode_bs_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(ulaw_decode_bs_sptr self, int multiple)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(ulaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(ulaw_decode_bs_sptr self) -> double"""
        return _vocoder_swig.ulaw_decode_bs_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(ulaw_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.ulaw_decode_bs_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(ulaw_decode_bs_sptr self) -> uint64_t"""
        return _vocoder_swig.ulaw_decode_bs_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(ulaw_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.ulaw_decode_bs_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(ulaw_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.ulaw_decode_bs_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(ulaw_decode_bs_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.ulaw_decode_bs_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(ulaw_decode_bs_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.ulaw_decode_bs_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(ulaw_decode_bs_sptr self, std::string level)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(ulaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_decode_bs_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(ulaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(ulaw_decode_bs_sptr self, int m)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(ulaw_decode_bs_sptr self)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(ulaw_decode_bs_sptr self) -> bool"""
        return _vocoder_swig.ulaw_decode_bs_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(ulaw_decode_bs_sptr self, int m)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(ulaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(ulaw_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.ulaw_decode_bs_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(ulaw_decode_bs_sptr self, long max_output_buffer)
        set_max_output_buffer(ulaw_decode_bs_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(ulaw_decode_bs_sptr self, int i) -> long"""
        return _vocoder_swig.ulaw_decode_bs_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(ulaw_decode_bs_sptr self, long min_output_buffer)
        set_min_output_buffer(ulaw_decode_bs_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(ulaw_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full(ulaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(ulaw_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_avg(ulaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(ulaw_decode_bs_sptr self, int which) -> float
        pc_input_buffers_full_var(ulaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(ulaw_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full(ulaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(ulaw_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_avg(ulaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(ulaw_decode_bs_sptr self, int which) -> float
        pc_output_buffers_full_var(ulaw_decode_bs_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(ulaw_decode_bs_sptr self) -> float"""
        return _vocoder_swig.ulaw_decode_bs_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(ulaw_decode_bs_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(ulaw_decode_bs_sptr self)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(ulaw_decode_bs_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.ulaw_decode_bs_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(ulaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(ulaw_decode_bs_sptr self) -> int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(ulaw_decode_bs_sptr self, int priority) -> int"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(ulaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_decode_bs_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(ulaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_decode_bs_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(ulaw_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(ulaw_decode_bs_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(ulaw_decode_bs_sptr self) -> long"""
        return _vocoder_swig.ulaw_decode_bs_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(ulaw_decode_bs_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(ulaw_decode_bs_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.ulaw_decode_bs_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(ulaw_decode_bs_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_decode_bs_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(ulaw_decode_bs_sptr self, std::string name)"""
        return _vocoder_swig.ulaw_decode_bs_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(ulaw_decode_bs_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.ulaw_decode_bs_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(ulaw_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(ulaw_decode_bs_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(ulaw_decode_bs_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.ulaw_decode_bs_sptr_message_subscribers(self, which_port)

# Register ulaw_decode_bs_sptr in _vocoder_swig:
_vocoder_swig.ulaw_decode_bs_sptr_swigregister(ulaw_decode_bs_sptr)


ulaw_decode_bs_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
ulaw_decode_bs = ulaw_decode_bs.make;

class ulaw_encode_sb_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::vocoder::ulaw_encode_sb > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(ulaw_encode_sb_sptr self) -> ulaw_encode_sb_sptr
        __init__(ulaw_encode_sb_sptr self, ulaw_encode_sb p) -> ulaw_encode_sb_sptr
        """
        _vocoder_swig.ulaw_encode_sb_sptr_swiginit(self, _vocoder_swig.new_ulaw_encode_sb_sptr(*args))

    def __deref__(self) -> "gr::vocoder::ulaw_encode_sb *":
        r"""__deref__(ulaw_encode_sb_sptr self) -> ulaw_encode_sb"""
        return _vocoder_swig.ulaw_encode_sb_sptr___deref__(self)
    __swig_destroy__ = _vocoder_swig.delete_ulaw_encode_sb_sptr

    def make(self) -> "gr::vocoder::ulaw_encode_sb::sptr":
        r"""make(ulaw_encode_sb_sptr self) -> ulaw_encode_sb_sptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_make(self)

    def history(self) -> "unsigned int":
        r"""history(ulaw_encode_sb_sptr self) -> unsigned int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(ulaw_encode_sb_sptr self, int which, int delay)
        declare_sample_delay(ulaw_encode_sb_sptr self, unsigned int delay)
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(ulaw_encode_sb_sptr self, int which) -> unsigned int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(ulaw_encode_sb_sptr self, int multiple)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(ulaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(ulaw_encode_sb_sptr self) -> double"""
        return _vocoder_swig.ulaw_encode_sb_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(ulaw_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.ulaw_encode_sb_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(ulaw_encode_sb_sptr self) -> uint64_t"""
        return _vocoder_swig.ulaw_encode_sb_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(ulaw_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.ulaw_encode_sb_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(ulaw_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.ulaw_encode_sb_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(ulaw_encode_sb_sptr self, unsigned int which_input) -> uint64_t"""
        return _vocoder_swig.ulaw_encode_sb_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(ulaw_encode_sb_sptr self, unsigned int which_output) -> uint64_t"""
        return _vocoder_swig.ulaw_encode_sb_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(ulaw_encode_sb_sptr self, std::string level)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(ulaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_encode_sb_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(ulaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(ulaw_encode_sb_sptr self, int m)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(ulaw_encode_sb_sptr self)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(ulaw_encode_sb_sptr self) -> bool"""
        return _vocoder_swig.ulaw_encode_sb_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(ulaw_encode_sb_sptr self, int m)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(ulaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(ulaw_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.ulaw_encode_sb_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(ulaw_encode_sb_sptr self, long max_output_buffer)
        set_max_output_buffer(ulaw_encode_sb_sptr self, int port, long max_output_buffer)
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(ulaw_encode_sb_sptr self, int i) -> long"""
        return _vocoder_swig.ulaw_encode_sb_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(ulaw_encode_sb_sptr self, long min_output_buffer)
        set_min_output_buffer(ulaw_encode_sb_sptr self, int port, long min_output_buffer)
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(ulaw_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full(ulaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(ulaw_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_avg(ulaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(ulaw_encode_sb_sptr self, int which) -> float
        pc_input_buffers_full_var(ulaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(ulaw_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full(ulaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(ulaw_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_avg(ulaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(ulaw_encode_sb_sptr self, int which) -> float
        pc_output_buffers_full_var(ulaw_encode_sb_sptr self) -> pmt_vector_float
        """
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(ulaw_encode_sb_sptr self) -> float"""
        return _vocoder_swig.ulaw_encode_sb_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(ulaw_encode_sb_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(ulaw_encode_sb_sptr self)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(ulaw_encode_sb_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _vocoder_swig.ulaw_encode_sb_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(ulaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(ulaw_encode_sb_sptr self) -> int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(ulaw_encode_sb_sptr self, int priority) -> int"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(ulaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_encode_sb_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(ulaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_encode_sb_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(ulaw_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(ulaw_encode_sb_sptr self) -> io_signature_sptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(ulaw_encode_sb_sptr self) -> long"""
        return _vocoder_swig.ulaw_encode_sb_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(ulaw_encode_sb_sptr self) -> basic_block_sptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(ulaw_encode_sb_sptr self, int ninputs, int noutputs) -> bool"""
        return _vocoder_swig.ulaw_encode_sb_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(ulaw_encode_sb_sptr self) -> std::string"""
        return _vocoder_swig.ulaw_encode_sb_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(ulaw_encode_sb_sptr self, std::string name)"""
        return _vocoder_swig.ulaw_encode_sb_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(ulaw_encode_sb_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _vocoder_swig.ulaw_encode_sb_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(ulaw_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(ulaw_encode_sb_sptr self) -> swig_pmt_ptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(ulaw_encode_sb_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _vocoder_swig.ulaw_encode_sb_sptr_message_subscribers(self, which_port)

# Register ulaw_encode_sb_sptr in _vocoder_swig:
_vocoder_swig.ulaw_encode_sb_sptr_swigregister(ulaw_encode_sb_sptr)


ulaw_encode_sb_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
ulaw_encode_sb = ulaw_encode_sb.make;



